@@ -5,8 +5,8 @@
 
 #include "ev-document-type-builtins.h"
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-annotation.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-annotation.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-annotation.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-annotation.h"
 GType
 ev_annotation_type_get_type (void)
 {
@@ -56,8 +56,8 @@ ev_annotation_text_icon_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-document-annotations.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-document-annotations.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-document-annotations.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-document-annotations.h"
 GType
 ev_annotations_save_mask_get_type (void)
 {
@@ -87,8 +87,8 @@ ev_annotations_save_mask_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-document.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-document.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-document.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-document.h"
 GType
 ev_document_error_get_type (void)
 {
@@ -109,8 +109,8 @@ ev_document_error_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-document-info.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-document-info.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-document-info.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-document-info.h"
 GType
 ev_document_layout_get_type (void)
 {
@@ -243,8 +243,8 @@ ev_document_info_fields_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-file-exporter.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-file-exporter.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-file-exporter.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-file-exporter.h"
 GType
 ev_file_exporter_format_get_type (void)
 {
@@ -293,8 +293,8 @@ ev_file_exporter_capabilities_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-file-helpers.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-file-helpers.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-file-helpers.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-file-helpers.h"
 GType
 ev_compression_type_get_type (void)
 {
@@ -305,6 +305,7 @@ ev_compression_type_get_type (void)
       { EV_COMPRESSION_NONE, "EV_COMPRESSION_NONE", "none" },
       { EV_COMPRESSION_BZIP2, "EV_COMPRESSION_BZIP2", "bzip2" },
       { EV_COMPRESSION_GZIP, "EV_COMPRESSION_GZIP", "gzip" },
+      { EV_COMPRESSION_LZMA, "EV_COMPRESSION_LZMA", "lzma" },
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
@@ -316,8 +317,8 @@ ev_compression_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-form-field.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-form-field.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-form-field.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-form-field.h"
 GType
 ev_form_field_text_type_get_type (void)
 {
@@ -380,8 +381,8 @@ ev_form_field_choice_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-link-action.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-link-action.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-link-action.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-link-action.h"
 GType
 ev_link_action_type_get_type (void)
 {
@@ -394,6 +395,7 @@ ev_link_action_type_get_type (void)
       { EV_LINK_ACTION_TYPE_EXTERNAL_URI, "EV_LINK_ACTION_TYPE_EXTERNAL_URI", "external-uri" },
       { EV_LINK_ACTION_TYPE_LAUNCH, "EV_LINK_ACTION_TYPE_LAUNCH", "launch" },
       { EV_LINK_ACTION_TYPE_NAMED, "EV_LINK_ACTION_TYPE_NAMED", "named" },
+      { EV_LINK_ACTION_TYPE_LAYERS_STATE, "EV_LINK_ACTION_TYPE_LAYERS_STATE", "layers-state" },
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
@@ -405,8 +407,8 @@ ev_link_action_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-link-dest.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-link-dest.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-link-dest.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-link-dest.h"
 GType
 ev_link_dest_type_get_type (void)
 {
@@ -422,6 +424,7 @@ ev_link_dest_type_get_type (void)
       { EV_LINK_DEST_TYPE_FITR, "EV_LINK_DEST_TYPE_FITR", "fitr" },
       { EV_LINK_DEST_TYPE_NAMED, "EV_LINK_DEST_TYPE_NAMED", "named" },
       { EV_LINK_DEST_TYPE_PAGE_LABEL, "EV_LINK_DEST_TYPE_PAGE_LABEL", "page-label" },
+      { EV_LINK_DEST_TYPE_HLINK, "EV_LINK_DEST_TYPE_HLINK", "hlink" },
       { EV_LINK_DEST_TYPE_UNKNOWN, "EV_LINK_DEST_TYPE_UNKNOWN", "unknown" },
       { 0, NULL, NULL }
     };
@@ -434,8 +437,8 @@ ev_link_dest_type_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-selection.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-selection.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-selection.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-selection.h"
 GType
 ev_selection_style_get_type (void)
 {
@@ -457,8 +460,8 @@ ev_selection_style_get_type (void)
   return g_define_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-transition-effect.h" */
-#include "/usr/src/ports/atril/atril-1.8.1-1.i686/src/atril-1.8.1/libdocument/ev-transition-effect.h"
+/* enumerations from "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-transition-effect.h" */
+#include "/usr/src/ports/atril/atril-1.10.2-1.x86_64/src/atril-1.10.2/libdocument/ev-transition-effect.h"
 GType
 ev_transition_effect_type_get_type (void)
 {
